@@ -371,6 +371,40 @@ class Backbone(object):
                 classroom.uid = res_data['uid']
             print("##### already create {} {}/{} classroom ####".format(classroom.name, index, len(classrooms)))
 
+    def clear_meeting_rooms(self):
+        """
+        清除未开始的会议室
+        :return:
+        """
+        future_meeting_rooms = self.nirvana_requester.get_meeting_room_list(params={"state": 3})
+        if future_meeting_rooms:
+            for f_room in future_meeting_rooms.get("results", []):
+                self.nirvana_requester.delete_meeting_room(f_room["uid"])
+
+    def create_meeting_rooms(self, meeting_rooms):
+        """
+        同步会议室信息
+        :return:
+        """
+        print(">>>Create MeetingRoom")
+        index = 0
+        for m_room in meeting_rooms:
+            index += 1
+            m_room.classroom_id = self.classroom_map.get(str(m_room.classroom_number))
+            for user_number in m_room.user_numbers:
+                user_id = self.teacher_map.get(user_number) or self.student_map.get(user_number)
+                if user_id:
+                    m_room.user.append(user_id)
+            res_data = self.nirvana_requester.create_classroom(m_room.nirvana_data)
+            m_room.uid = res_data['uid']
+            role_data = m_room.nirvana_rule_data
+            if role_data:
+                self.nirvana_requester.create_meeting_room_rule(role_data)
+            user_data = m_room.get_user_data()
+            bind_user_data = {"meeting": res_data['uid'], "user": user_data["new_user"]}
+            self.nirvana_requester.bind_meeting_room_user(bind_user_data)
+            print("##### already create {} {}/{} meeting_rooms ####".format(m_room.name, index, len(meeting_rooms)))
+
     def relate_course_field(self):
         """
         将模型Course中的字段通过映射，转换为uid。(班牌后台接口结构)
@@ -586,6 +620,13 @@ class Backbone(object):
                     room_list.extend(room)
         return room_list
 
+    def upload_meeting_rooms(self, meeting_rooms):
+        self.wrap_student_map()
+        self.wrap_teacher_map()
+        self.wrap_classroom_map()
+        self.clear_meeting_rooms()
+        self.create_meeting_rooms(meeting_rooms)
+
 
 class BackboneV1(Backbone):
     def __init__(self, school_id):
